@@ -29,8 +29,9 @@ class Lease(SequentialRecipe):
         except exc.NodeExists:
             log.warning("Lease for %s already obtained.", self.base_path)
 
-        callback = partial(asyncio.ensure_future, self.release(), loop=self.client.loop)
-        self.client.loop.call_later(duration.total_seconds(), callback)
+        callback = partial(asyncio.create_task, self.release())
+        loop = asyncio.get_running_loop()
+        loop.call_later(duration.total_seconds(), callback)
         return True
 
     async def release(self):
